pub enum SierraError {
Protocol {
code: ErrorCode,
message: Option<String>,
},
Redis(RedisError),
}Expand description
Errors that can occur when using the SierraDB client.
Variants
Protocol
A protocol-level error returned by the Sierra server
Redis(RedisError)
A Redis client error (connection, parsing, etc.)
Implementations
Sourceimpl SierraError
impl SierraError
Sourcepub fn from_redis_error(redis_error: RedisError) -> Self
pub fn from_redis_error(redis_error: RedisError) -> Self
Parse a Redis error response into a SierraError.
Sourcepub fn is_retryable(&self) -> bool
pub fn is_retryable(&self) -> bool
Check if this error indicates a temporary failure that should be retried.
Sourcepub fn is_cluster_issue(&self) -> bool
pub fn is_cluster_issue(&self) -> bool
Check if this error indicates a cluster availability issue.
Sourcepub fn is_client_error(&self) -> bool
pub fn is_client_error(&self) -> bool
Check if this error indicates a client argument error.
Sourcepub fn error_code(&self) -> Option<ErrorCode>
pub fn error_code(&self) -> Option<ErrorCode>
Get the error code if this is a protocol error.
Sourcepub fn retry_delay_ms(&self) -> Option<u64>
pub fn retry_delay_ms(&self) -> Option<u64>
Get a suggested retry delay in milliseconds for retryable errors. Returns None if the error should not be retried.