pub struct HelloResp {
pub server: String,
pub version: String,
pub peer_id: String,
pub num_partitions: u16,
}Fields
server: Stringversion: Stringpeer_id: Stringnum_partitions: u16Trait Implementations
Sourceimpl<'de> Deserialize<'de> for HelloResp
impl<'de> Deserialize<'de> for HelloResp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromRedisValue for HelloResp
impl FromRedisValue for HelloResp
Sourcefn from_redis_value(value: &Value) -> RedisResult<Self>
fn from_redis_value(value: &Value) -> RedisResult<Self>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_owned_redis_value(v: Value) -> Result<Self, RedisError>
fn from_owned_redis_value(v: Value) -> Result<Self, RedisError>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_redis_values(items: &[Value]) -> Result<Vec<Self>, RedisError>
fn from_redis_values(items: &[Value]) -> Result<Vec<Self>, RedisError>
Similar to
from_redis_value but constructs a vector of objects
from another vector of values. This primarily exists internally
to customize the behavior for vectors of tuples.Sourcefn from_owned_redis_values(items: Vec<Value>) -> Result<Vec<Self>, RedisError>
fn from_owned_redis_values(items: Vec<Value>) -> Result<Vec<Self>, RedisError>
The same as
from_redis_values, but takes a Vec<Value> instead
of a &[Value].Sourcefn from_each_owned_redis_values(
items: Vec<Value>,
) -> Vec<Result<Self, RedisError>>
fn from_each_owned_redis_values( items: Vec<Value>, ) -> Vec<Result<Self, RedisError>>
The same as
from_owned_redis_values, but returns a result for each
conversion to make handling them case-by-case possible.Sourcefn from_owned_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, RedisError>
fn from_owned_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, RedisError>
Convert bytes to a single element vector.
impl Eq for HelloResp
impl StructuralPartialEq for HelloResp