pub struct MultiAppendInfo {
pub partition_key: Uuid,
pub partition_id: u16,
pub first_partition_sequence: u64,
pub last_partition_sequence: u64,
pub events: Vec<EventInfo>,
}Expand description
Information about a multi-event append transaction.
Fields
partition_key: Uuidpartition_id: u16first_partition_sequence: u64last_partition_sequence: u64events: Vec<EventInfo>Trait Implementations
Sourceimpl Clone for MultiAppendInfo
impl Clone for MultiAppendInfo
Sourcefn clone(&self) -> MultiAppendInfo
fn clone(&self) -> MultiAppendInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MultiAppendInfo
impl Debug for MultiAppendInfo
Sourceimpl<'de> Deserialize<'de> for MultiAppendInfo
impl<'de> Deserialize<'de> for MultiAppendInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromRedisValue for MultiAppendInfo
impl FromRedisValue for MultiAppendInfo
Sourcefn from_redis_value(value: &Value) -> RedisResult<Self>
fn from_redis_value(value: &Value) -> RedisResult<Self>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_owned_redis_value(v: Value) -> Result<Self, RedisError>
fn from_owned_redis_value(v: Value) -> Result<Self, RedisError>
Given a redis
Value this attempts to convert it into the given
destination type. If that fails because it’s not compatible an
appropriate error is generated.Sourcefn from_redis_values(items: &[Value]) -> Result<Vec<Self>, RedisError>
fn from_redis_values(items: &[Value]) -> Result<Vec<Self>, RedisError>
Similar to
from_redis_value but constructs a vector of objects
from another vector of values. This primarily exists internally
to customize the behavior for vectors of tuples.Sourcefn from_owned_redis_values(items: Vec<Value>) -> Result<Vec<Self>, RedisError>
fn from_owned_redis_values(items: Vec<Value>) -> Result<Vec<Self>, RedisError>
The same as
from_redis_values, but takes a Vec<Value> instead
of a &[Value].Sourcefn from_each_owned_redis_values(
items: Vec<Value>,
) -> Vec<Result<Self, RedisError>>
fn from_each_owned_redis_values( items: Vec<Value>, ) -> Vec<Result<Self, RedisError>>
The same as
from_owned_redis_values, but returns a result for each
conversion to make handling them case-by-case possible.Sourcefn from_owned_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, RedisError>
fn from_owned_byte_vec(_vec: Vec<u8>) -> Result<Vec<Self>, RedisError>
Convert bytes to a single element vector.
Sourceimpl PartialEq for MultiAppendInfo
impl PartialEq for MultiAppendInfo
Sourceimpl Serialize for MultiAppendInfo
impl Serialize for MultiAppendInfo
impl Eq for MultiAppendInfo
impl StructuralPartialEq for MultiAppendInfo